# Other open-source projects related to fair division

## Python projects

**[PrefLib-Tools](https://github.com/PrefLib/PrefLib-Tools)** - tools for working with the open library of ordinal preferences library `PrefLib`. By Nicholas Mattei.

**[Apportionment](https://github.com/martinlackner/apportionment)** - algorithms for fair allocation of identical items among agents with different entitlements (e.g. parliament seats among parties). By Martin Lackner.

**[ABCVoting](https://github.com/martinlackner/abcvoting)** - Approval-Based Committee voting rules. Many of these rules guarantee fairness properties for groups, such as justified representation. By Martin Lackner.

**[DPR](https://git.tu-berlin.de/jonas.israel/dpr/)** - Dynamic Proportional Ranking. Extends and adapts approval-based committee voting rules to return a ranking that takes the past into account. By Jonas Israel.

**[FairDiv](https://gricad-gitlab.univ-grenoble-alpes.fr/bouveres/fairdiv/)** - fair division of indivisible items. Contains: an instance generator; combinatorial optimization tools to find and count solutions satisfying some tests; maximin-share, minimax-share, ceei, Pareto-optimality test. By Sylvain Bouveret.

**[NumberPartitioning](https://github.com/fuglede/numberpartitioning)** - algorithms for fair allocation of items among agents with identical valuations (- balanced partitioning of numbers). By Søren Fuglede Jørgensen.

**[Python-vote-core](https://github.com/the-maldridge/python-vote-core)** - various voting rules in Python. by Brad Beatle. Python 3 fork by Michael Aldridge.

**[Matching](https://github.com/daffidwilde/matching)** - algorithms for stable marriage, hospital-resident assignment, student-allocation, and stable roommates. By Henry Wilde and Vince Knight.

**[Fair family allocation](https://github.com/erelsgl/fair-family-allocation)** - algorithms for democratic-fair allocation of indivisible goods. Based on a paper by Warut Suksompong and Erel Segal-Halevi.

## Projects in other languages

**[Spliddit](https://github.com/jogo279/spliddit)** - Ruby code for the website [spliddit.org](http://spliddit.org). By Jonathan Goldman, Nisarg Shah, David Kurokawa and Ariel Procaccia.
 
**[Stanford PB](https://github.com/StanfordCDT/pb)** - Participatory budgeting platform in Ruby. By Sukolsak Sakshuwong and others.

